@@ -29,10 +29,7 @@
 #include <GL/glut.h>
 #include <cstring>
 
-#ifndef _WIN32
-#else
-#  include <glext.h>
-#endif
+#include "glext.h"
 
 using namespace std;
 
